@@ -2,10 +2,10 @@
 
 #
 # Creates distribution files
-# $Id: make-distrib.sh 1161 2007-06-30 19:06:17Z vaclavslavik $
+# $Id: make-distrib.sh 1253 2007-12-11 11:19:00Z vaclavslavik $
 #
 
-VERSION=1.3.7
+VERSION=1.3.9
 
 #(
 #cd docs_classes
@@ -22,7 +22,7 @@ for i in *.po ; do msgfmt -o `basename $i .po`.mo $i ; done
 find_unix_files()
 {
   (find . -maxdepth 1 -type f ; \
-  find admin locales src docs install macosx win32 -type f) | \
+  find admin build locales src docs install macosx win32 -type f) | \
     grep -v '/win32-' | \
     grep -v '/\.svn' | \
     grep -v '/\.bakefile_gen.state' | \
