@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2007 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.cpp 1116 2007-06-16 20:56:34Z vaclavslavik $
+ *  $Id: catalog.cpp 1183 2007-11-09 10:36:00Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -41,6 +41,8 @@
 #include <wx/msgdlg.h>
 #include <wx/filename.h>
 
+#include <set>
+
 #include "catalog.h"
 #include "digger.h"
 #include "gexecute.h"
@@ -49,10 +51,6 @@
 #include "isocodes.h"
 
 
-#include "wx/arrimpl.cpp"
-WX_DEFINE_OBJARRAY(CatalogDataArray)
-WX_DEFINE_OBJARRAY(CatalogDeletedDataArray)
-
 
 // ----------------------------------------------------------------------
 // Textfile processing utilities:
@@ -503,7 +501,10 @@ bool CatalogParser::Parse()
     wxString line, dummy;
     wxString mflags, mstr, msgid_plural, mcomment;
     wxArrayString mrefs, mautocomments, mtranslations;
+    wxArrayString msgid_old;
     bool has_plural = false;
+    bool has_context = false;
+    wxString msgctxt;
     unsigned mlinenum;
 
     line = m_textFile->GetFirstLine();
@@ -513,7 +514,7 @@ bool CatalogParser::Parse()
     {
         // ignore empty special tags (except for automatic comments which we
         // DO want to preserve):
-        while (line == _T("#,") || line == _T("#:"))
+        while (line == _T("#,") || line == _T("#:") || line == _T("#|"))
             line = ReadTextLine(m_textFile);
 
         // flags:
@@ -551,6 +552,30 @@ bool CatalogParser::Parse()
             line = ReadTextLine(m_textFile);
         }
 
+        // previous msgid value:
+        else if (ReadParam(line, _T("#| "), dummy))
+        {
+            msgid_old.Add(dummy);
+            line = ReadTextLine(m_textFile);
+        }
+
+        // msgctxt:
+        else if (ReadParam(line, _T("msgctxt \""), dummy) ||
+                 ReadParam(line, _T("msgctxt\t\""), dummy))
+        {
+            has_context = true;
+            msgctxt = dummy.RemoveLast();
+            while (!(line = ReadTextLine(m_textFile)).empty())
+            {
+                if (line[0u] == _T('\t'))
+                    line.Remove(0, 1);
+                if (line[0u] == _T('"') && line.Last() == _T('"'))
+                    msgctxt += line.Mid(1, line.Length() - 2);
+                else
+                    break;
+            }
+        }
+
         // msgid:
         else if (ReadParam(line, _T("msgid \""), dummy) ||
                  ReadParam(line, _T("msgid\t\""), dummy))
@@ -609,17 +634,20 @@ bool CatalogParser::Parse()
             mtranslations.Add(str);
 
             if (!OnEntry(mstr, wxEmptyString, false,
+                         has_context, msgctxt,
                          mtranslations,
-                         mflags, mrefs, mcomment, mautocomments, mlinenum))
+                         mflags, mrefs, mcomment, mautocomments, msgid_old,
+                         mlinenum))
             {
                 return false;
             }
 
-            mcomment = mstr = msgid_plural = mflags = wxEmptyString;
-            has_plural = false;
+            mcomment = mstr = msgid_plural = msgctxt = mflags = wxEmptyString;
+            has_plural = has_context = false;
             mrefs.Clear();
             mautocomments.Clear();
             mtranslations.Clear();
+            msgid_old.Clear();
         }
 
         // msgstr[i]:
@@ -659,17 +687,20 @@ bool CatalogParser::Parse()
             }
 
             if (!OnEntry(mstr, msgid_plural, true,
+                         has_context, msgctxt,
                          mtranslations,
-                         mflags, mrefs, mcomment, mautocomments, mlinenum))
+                         mflags, mrefs, mcomment, mautocomments, msgid_old,
+                         mlinenum))
             {
                 return false;
             }
 
-            mcomment = mstr = msgid_plural = mflags = wxEmptyString;
-            has_plural = false;
+            mcomment = mstr = msgid_plural = msgctxt = mflags = wxEmptyString;
+            has_plural = has_context = false;
             mrefs.Clear();
             mautocomments.Clear();
             mtranslations.Clear();
+            msgid_old.Clear();
         }
 
         // deleted lines:
@@ -697,6 +728,7 @@ bool CatalogParser::Parse()
             mrefs.Clear();
             mautocomments.Clear();
             mtranslations.Clear();
+            msgid_old.Clear();
         }
 
         // comment:
@@ -739,38 +771,30 @@ class CharsetInfoFinder : public CatalogParser
         virtual bool OnEntry(const wxString& msgid,
                              const wxString& msgid_plural,
                              bool has_plural,
+                             bool has_context,
+                             const wxString& context,
                              const wxArrayString& mtranslations,
                              const wxString& flags,
                              const wxArrayString& references,
                              const wxString& comment,
                              const wxArrayString& autocomments,
-                             unsigned lineNumber);
-
+                             const wxArrayString& msgid_old,
+                             unsigned lineNumber)
+        {
+            if (msgid.empty())
+            {
+                // gettext header:
+                Catalog::HeaderData hdr;
+                hdr.FromString(mtranslations[0]);
+                m_charset = hdr.Charset;
+                if (m_charset == _T("CHARSET"))
+                    m_charset = _T("iso-8859-1");
+                return false; // stop parsing
+            }
+            return true;
+        }
 };
 
-bool CharsetInfoFinder::OnEntry(const wxString& msgid,
-                                const wxString& msgid_plural,
-                                bool has_plural,
-                                const wxArrayString& mtranslations,
-                                const wxString& flags,
-                                const wxArrayString& references,
-                                const wxString& comment,
-                                const wxArrayString& autocomments,
-                                unsigned lineNumber)
-{
-    if (msgid.empty())
-    {
-        // gettext header:
-        Catalog::HeaderData hdr;
-        hdr.FromString(mtranslations[0]);
-        m_charset = hdr.Charset;
-        if (m_charset == _T("CHARSET"))
-            m_charset = _T("iso-8859-1");
-        return false; // stop parsing
-    }
-    return true;
-}
-
 
 
 class LoadParser : public CatalogParser
@@ -785,11 +809,14 @@ class LoadParser : public CatalogParser
         virtual bool OnEntry(const wxString& msgid,
                              const wxString& msgid_plural,
                              bool has_plural,
+                             bool has_context,
+                             const wxString& context,
                              const wxArrayString& mtranslations,
                              const wxString& flags,
                              const wxArrayString& references,
                              const wxString& comment,
                              const wxArrayString& autocomments,
+                             const wxArrayString& msgid_old,
                              unsigned lineNumber);
 
         virtual bool OnDeletedEntry(const wxArrayString& deletedLines,
@@ -804,11 +831,14 @@ class LoadParser : public CatalogParser
 bool LoadParser::OnEntry(const wxString& msgid,
                          const wxString& msgid_plural,
                          bool has_plural,
+                         bool has_context,
+                         const wxString& context,
                          const wxArrayString& mtranslations,
                          const wxString& flags,
                          const wxArrayString& references,
                          const wxString& comment,
                          const wxArrayString& autocomments,
+                         const wxArrayString& msgid_old,
                          unsigned lineNumber)
 {
     if (msgid.empty())
@@ -819,18 +849,21 @@ bool LoadParser::OnEntry(const wxString& msgid,
     }
     else
     {
-        CatalogData *d = new CatalogData(wxEmptyString, wxEmptyString);
-        if (!flags.empty()) d->SetFlags(flags);
-        d->SetString(msgid);
+        CatalogData d;
+        if (!flags.empty()) d.SetFlags(flags);
+        d.SetString(msgid);
         if (has_plural)
-            d->SetPluralString(msgid_plural);
-        d->SetTranslations(mtranslations);
-        d->SetComment(comment);
-        d->SetLineNumber(lineNumber);
+            d.SetPluralString(msgid_plural);
+        if (has_context)
+            d.SetContext(context);
+        d.SetTranslations(mtranslations);
+        d.SetComment(comment);
+        d.SetLineNumber(lineNumber);
         for (size_t i = 0; i < references.GetCount(); i++)
-            d->AddReference(references[i]);
+            d.AddReference(references[i]);
         for (size_t i = 0; i < autocomments.GetCount(); i++)
-            d->AddAutoComments(autocomments[i]);
+            d.AddAutoComments(autocomments[i]);
+        d.SetOldMsgid(msgid_old);
         m_catalog->AddItem(d);
     }
     return true;
@@ -843,13 +876,13 @@ bool LoadParser::OnDeletedEntry(const wxArrayString& deletedLines,
                                 const wxArrayString& autocomments,
                                 unsigned lineNumber)
 {
-    CatalogDeletedData *d = new CatalogDeletedData(wxArrayString());
-    if (!flags.empty()) d->SetFlags(flags);
-    d->SetDeletedLines(deletedLines);
-    d->SetComment(comment);
-    d->SetLineNumber(lineNumber);
+    CatalogDeletedData d;
+    if (!flags.empty()) d.SetFlags(flags);
+    d.SetDeletedLines(deletedLines);
+    d.SetComment(comment);
+    d.SetLineNumber(lineNumber);
     for (size_t i = 0; i < autocomments.GetCount(); i++)
-      d->AddAutoComments(autocomments[i]);
+      d.AddAutoComments(autocomments[i]);
     m_catalog->AddDeletedItem(d);
 
     return true;
@@ -863,8 +896,6 @@ bool LoadParser::OnDeletedEntry(const wxArrayString& deletedLines,
 
 Catalog::Catalog()
 {
-    m_data = new wxHashTable(wxKEY_STRING);
-    m_count = 0;
     m_isOk = true;
     m_header.BasePath = wxEmptyString;
     for(int i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
@@ -877,14 +908,11 @@ Catalog::Catalog()
 Catalog::~Catalog()
 {
     Clear();
-    delete m_data;
 }
 
 
 Catalog::Catalog(const wxString& po_file)
 {
-    m_data = NULL;
-    m_count = 0;
     m_isOk = Load(po_file);
 }
 
@@ -934,16 +962,12 @@ bool Catalog::Load(const wxString& po_file)
     wxTextFile f;
 
     Clear();
-    delete m_data; m_data = NULL;
-    m_count = 0;
     m_isOk = false;
     m_fileName = po_file;
     m_header.BasePath = wxEmptyString;
 
     /* Load the .po file: */
 
-    m_data = new wxHashTable(wxKEY_STRING);
-
     if (!f.Open(po_file, wxConvISO8859_1))
         return false;
 
@@ -975,9 +999,9 @@ bool Catalog::Load(const wxString& po_file)
     for (unsigned i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
     {
         if (m_header.Bookmarks[i] != -1 &&
-            m_header.Bookmarks[i] < (int)m_dataArray.GetCount())
+            m_header.Bookmarks[i] < (int)m_items.size())
         {
-            m_dataArray[m_header.Bookmarks[i]].SetBookmark(
+            m_items[m_header.Bookmarks[i]].SetBookmark(
                     static_cast<Bookmark>(i));
         }
     }
@@ -1047,36 +1071,31 @@ bool Catalog::Load(const wxString& po_file)
     return true;
 }
 
-void Catalog::AddItem(CatalogData *data)
+void Catalog::AddItem(const CatalogData& data)
 {
-    m_data->Put(data->GetString(), data);
-    m_dataArray.Add(data);
-    m_count++;
+    m_items.push_back(data);
 }
 
-void Catalog::AddDeletedItem(CatalogDeletedData *data)
+void Catalog::AddDeletedItem(const CatalogDeletedData& data)
 {
-    m_deletedItemsArray.Add(data);
+    m_deletedItems.push_back(data);
 }
 
 bool Catalog::HasDeletedItems()
 {
-    return !m_deletedItemsArray.empty();
+    return !m_deletedItems.empty();
 }
 
 void Catalog::RemoveDeletedItems()
 {
-    m_deletedItemsArray.Empty();
+    m_deletedItems.clear();
 }
 
 void Catalog::Clear()
 {
-    delete m_data;
-    m_dataArray.Empty();
-    m_deletedItemsArray.Empty();
+    m_items.clear();
+    m_deletedItems.clear();
     m_isOk = true;
-    m_count = 0;
-    m_data = new wxHashTable(wxKEY_STRING);
     for(int i = BOOKMARK_0; i < BOOKMARK_LAST; i++)
     {
         m_header.Bookmarks[i] = -1;
@@ -1088,14 +1107,14 @@ int Catalog::SetBookmark(int id, Bookmark bookmark)
     int result = (bookmark==NO_BOOKMARK)?-1:m_header.Bookmarks[bookmark];
 
     // unset previous bookmarks, if any
-    Bookmark bk = m_dataArray[id].GetBookmark();
+    Bookmark bk = m_items[id].GetBookmark();
     if (bk != NO_BOOKMARK)
         m_header.Bookmarks[bk] = -1;
     if (result > -1)
-        m_dataArray[result].SetBookmark(NO_BOOKMARK);
+        m_items[result].SetBookmark(NO_BOOKMARK);
 
     // set new bookmark
-    m_dataArray[id].SetBookmark(bookmark);
+    m_items[id].SetBookmark(bookmark);
     if (bookmark != NO_BOOKMARK)
         m_header.Bookmarks[bookmark] = id;
 
@@ -1201,11 +1220,6 @@ static wxString FormatStringForFile(const wxString& text)
 
 bool Catalog::Save(const wxString& po_file, bool save_mo)
 {
-    CatalogData *data;
-    CatalogDeletedData *deletedItem;
-    wxString dummy;
-    size_t i;
-    int j;
     wxTextFileType crlfOrig, crlf;
     bool crlfPreserve;
     wxTextFile f;
@@ -1258,7 +1272,7 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     if (!wxFileExists(po_file) || !f.Open(po_file, wxConvISO8859_1))
         if (!f.Create(po_file))
             return false;
-    for (j = f.GetLineCount() - 1; j >= 0; j--)
+    for (int j = f.GetLineCount() - 1; j >= 0; j--)
         f.RemoveLine(j);
 
 
@@ -1272,61 +1286,67 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     SaveMultiLines(f, pohdr);
     f.AddLine(wxEmptyString);
 
-    for (i = 0; i < m_dataArray.GetCount(); i++)
+    for (unsigned i = 0; i < m_items.size(); i++)
     {
-        data = &(m_dataArray[i]);
-        SaveMultiLines(f, data->GetComment());
-        for (unsigned i = 0; i < data->GetAutoComments().GetCount(); i++)
+        CatalogData& data = m_items[i];
+        SaveMultiLines(f, data.GetComment());
+        for (unsigned i = 0; i < data.GetAutoComments().GetCount(); i++)
         {
-            if (data->GetAutoComments()[i].empty())
+            if (data.GetAutoComments()[i].empty())
               f.AddLine(_T("#."));
             else
-              f.AddLine(_T("#. ") + data->GetAutoComments()[i]);
+              f.AddLine(_T("#. ") + data.GetAutoComments()[i]);
         }
-        for (unsigned i = 0; i < data->GetReferences().GetCount(); i++)
-            f.AddLine(_T("#: ") + data->GetReferences()[i]);
-        dummy = data->GetFlags();
+        for (unsigned i = 0; i < data.GetReferences().GetCount(); i++)
+            f.AddLine(_T("#: ") + data.GetReferences()[i]);
+        wxString dummy = data.GetFlags();
         if (!dummy.empty())
             f.AddLine(dummy);
-        dummy = FormatStringForFile(data->GetString());
-        data->SetLineNumber(f.GetLineCount()+1);
-        SaveMultiLines(f, _T("msgid \"") + dummy + _T("\""));
-        if (data->HasPlural())
+        for (unsigned i = 0; i < data.GetOldMsgid().GetCount(); i++)
+            f.AddLine(_T("#| ") + data.GetOldMsgid()[i]);
+        if ( data.HasContext() )
         {
-            dummy = FormatStringForFile(data->GetPluralString());
+            SaveMultiLines(f, _T("msgctxt \"") + FormatStringForFile(data.GetContext()) + _T("\""));
+        }
+        dummy = FormatStringForFile(data.GetString());
+        data.SetLineNumber(f.GetLineCount()+1);
+        SaveMultiLines(f, _T("msgid \"") + dummy + _T("\""));
+        if (data.HasPlural())
+        {
+            dummy = FormatStringForFile(data.GetPluralString());
             SaveMultiLines(f, _T("msgid_plural \"") + dummy + _T("\""));
 
-            for (size_t i = 0; i < data->GetNumberOfTranslations(); i++)
+            for (size_t i = 0; i < data.GetNumberOfTranslations(); i++)
             {
-                dummy = FormatStringForFile(data->GetTranslation(i));
+                dummy = FormatStringForFile(data.GetTranslation(i));
                 wxString hdr = wxString::Format(_T("msgstr[%u] \""), i);
                 SaveMultiLines(f, hdr + dummy + _T("\""));
             }
         }
         else
         {
-            dummy = FormatStringForFile(data->GetTranslation());
+            dummy = FormatStringForFile(data.GetTranslation());
             SaveMultiLines(f, _T("msgstr \"") + dummy + _T("\""));
         }
         f.AddLine(wxEmptyString);
     }
 
     // Write back deleted items in the file so that they're not lost
-    for (i = 0; i < m_deletedItemsArray.GetCount(); i++)
+    for (unsigned i = 0; i < m_deletedItems.size(); i++)
     {
-        deletedItem = &(m_deletedItemsArray[i]);
-        SaveMultiLines(f, deletedItem->GetComment());
-        for (unsigned i = 0; i < deletedItem->GetAutoComments().GetCount(); i++)
-            f.AddLine(_T("#. ") + deletedItem->GetAutoComments()[i]);
-        for (unsigned i = 0; i < deletedItem->GetReferences().GetCount(); i++)
-            f.AddLine(_T("#: ") + deletedItem->GetReferences()[i]);
-        dummy = deletedItem->GetFlags();
+        CatalogDeletedData& deletedItem = m_deletedItems[i];
+        SaveMultiLines(f, deletedItem.GetComment());
+        for (unsigned i = 0; i < deletedItem.GetAutoComments().GetCount(); i++)
+            f.AddLine(_T("#. ") + deletedItem.GetAutoComments()[i]);
+        for (unsigned i = 0; i < deletedItem.GetReferences().GetCount(); i++)
+            f.AddLine(_T("#: ") + deletedItem.GetReferences()[i]);
+        wxString dummy = deletedItem.GetFlags();
         if (!dummy.empty())
             f.AddLine(dummy);
-        deletedItem->SetLineNumber(f.GetLineCount()+1);
+        deletedItem.SetLineNumber(f.GetLineCount()+1);
 
-        for (size_t j = 0; j < deletedItem->GetDeletedLines().GetCount(); j++)
-            f.AddLine(deletedItem->GetDeletedLines()[j]);
+        for (size_t j = 0; j < deletedItem.GetDeletedLines().GetCount(); j++)
+            f.AddLine(deletedItem.GetDeletedLines()[j]);
 
         f.AddLine(wxEmptyString);
     }
@@ -1335,7 +1355,7 @@ bool Catalog::Save(const wxString& po_file, bool save_mo)
     f.Write(crlf, encConv);
     f.Close();
 
-    /* poEdit < 1.3.0 used to save additional info in .po.poedit file. It's
+    /* Poedit < 1.3.0 used to save additional info in .po.poedit file. It's
        not used anymore, so delete the file if it exists: */
     if (wxFileExists(po_file + _T(".poedit")))
     {
@@ -1459,10 +1479,7 @@ bool Catalog::Merge(Catalog *refcat)
                        tmp2 + _T("\" \"") + tmp1 + _T("\""));
     if (succ)
     {
-        Catalog *c = new Catalog(tmp3);
-        Clear();
-        Append(*c);
-        delete c;
+        Load(tmp3);
     }
 
     wxRemoveFile(tmp1);
@@ -1477,19 +1494,31 @@ bool Catalog::Merge(Catalog *refcat)
 
 
 void Catalog::GetMergeSummary(Catalog *refcat,
-                          wxArrayString& snew, wxArrayString& sobsolete)
+                              wxArrayString& snew, wxArrayString& sobsolete)
 {
-    snew.Empty();
-    sobsolete.Empty();
+    wxASSERT( snew.empty() );
+    wxASSERT( sbsolete.empty() );
+
+    std::set<wxString> strsThis, strsRef;
+
+    for ( unsigned i = 0; i < GetCount(); i++ )
+        strsThis.insert((*this)[i].GetString());
+    for ( unsigned i = 0; i < refcat->GetCount(); i++ )
+        strsRef.insert((*refcat)[i].GetString());
+
     unsigned i;
 
     for (i = 0; i < GetCount(); i++)
-        if (refcat->FindItem((*this)[i].GetString()) == NULL)
-        sobsolete.Add((*this)[i].GetString());
+    {
+        if (strsRef.find((*this)[i].GetString()) == strsRef.end())
+            sobsolete.Add((*this)[i].GetString());
+    }
 
     for (i = 0; i < refcat->GetCount(); i++)
-        if (FindItem((*refcat)[i].GetString()) == NULL)
-        snew.Add((*refcat)[i].GetString());
+    {
+        if (strsThis.find((*refcat)[i].GetString()) == strsThis.end())
+            snew.Add((*refcat)[i].GetString());
+    }
 }
 
 bool Catalog::ShowMergeSummary(Catalog *refcat)
@@ -1507,12 +1536,6 @@ bool Catalog::ShowMergeSummary(Catalog *refcat)
 }
 
 
-CatalogData* Catalog::FindItem(const wxString& key) const
-{
-    return (CatalogData*) m_data->Get(key);
-}
-
-
 unsigned Catalog::GetPluralFormsCount() const
 {
     if (m_header.HasHeader(_T("Plural-Forms")))
@@ -1534,47 +1557,6 @@ unsigned Catalog::GetPluralFormsCount() const
 }
 
 
-bool Catalog::Translate(const wxString& key, const wxString& translation)
-{
-    CatalogData *d = FindItem(key);
-
-    if (d == NULL)
-        return false;
-    else
-    {
-        d->SetTranslation(translation);
-        return true;
-    }
-}
-
-
-void Catalog::Append(Catalog& cat)
-{
-    CatalogData *dt, *mydt;
-
-    for (unsigned i = 0; i < cat.GetCount(); i++)
-    {
-        dt = &(cat[i]);
-        mydt = FindItem(dt->GetString());
-        if (mydt == NULL)
-        {
-            mydt = new CatalogData(*dt);
-            m_data->Put(dt->GetString(), mydt);
-            m_dataArray.Add(mydt);
-            m_count++;
-        }
-        else
-        {
-            for (unsigned j = 0; j < dt->GetReferences().GetCount(); j++)
-                mydt->AddReference(dt->GetReferences()[j]);
-            if (!dt->GetTranslation().empty())
-                mydt->SetTranslation(dt->GetTranslation());
-            if (dt->IsFuzzy()) mydt->SetFuzzy(true);
-        }
-    }
-}
-
-
 void Catalog::GetStatistics(int *all, int *fuzzy, int *badtokens, int *untranslated)
 {
     if (all) *all = 0;
