@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2007 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE. 
  *
- *  $Id: catalog.h 1116 2007-06-16 20:56:34Z vaclavslavik $
+ *  $Id: catalog.h 1183 2007-11-09 10:36:00Z vaclavslavik $
  *
  *  Translations catalog
  *
@@ -30,19 +30,14 @@
 #ifndef _CATALOG_H_
 #define _CATALOG_H_
 
-#include <wx/hash.h>
-#include <wx/dynarray.h>
 #include <wx/encconv.h>
 #include <wx/regex.h>
+
 #include <vector>
+#include <map>
 
 class WXDLLEXPORT wxTextFile;
 
-class CatalogData;
-class CatalogDeletedData;
-WX_DECLARE_OBJARRAY(CatalogData, CatalogDataArray);
-WX_DECLARE_OBJARRAY(CatalogDeletedData, CatalogDeletedDataArray);
-
 /// The possible bookmarks for a given item
 typedef enum
 {
@@ -60,6 +55,336 @@ typedef enum
     BOOKMARK_LAST
 } Bookmark;
 
+/** This class holds information about one particular string.
+    This includes original string and its occurences in source code
+    (so-called references), translation and translation's status
+    (fuzzy, non translated, translated) and optional comment.
+
+    This class is mostly internal, used by Catalog to store data.
+ */
+class CatalogData
+{
+    public:
+        /// Ctor. Initializes the object with original string and translation.
+        CatalogData(const wxString& str = wxEmptyString,
+                    const wxString& str_plural = wxEmptyString)
+                : m_string(str),
+                  m_plural(str_plural),
+                  m_hasPlural(false),
+                  m_hasContext(false),
+                  m_references(),
+                  m_isFuzzy(false),
+                  m_isTranslated(false),
+                  m_isModified(false),
+                  m_isAutomatic(false),
+                  m_validity(Val_Unknown),
+                  m_lineNum(0),
+                  m_bookmark(NO_BOOKMARK) {}
+
+        CatalogData(const CatalogData& dt)
+                : m_string(dt.m_string),
+                  m_plural(dt.m_plural),
+                  m_hasPlural(dt.m_hasPlural),
+                  m_hasContext(dt.m_hasContext),
+                  m_context(dt.m_context),
+                  m_translations(dt.m_translations),
+                  m_references(dt.m_references),
+                  m_autocomments(dt.m_autocomments),
+                  m_oldMsgid(dt.m_oldMsgid),
+                  m_isFuzzy(dt.m_isFuzzy),
+                  m_isTranslated(dt.m_isTranslated),
+                  m_isModified(dt.m_isModified),
+                  m_isAutomatic(dt.m_isAutomatic),
+                  m_hasBadTokens(dt.m_hasBadTokens),
+                  m_moreFlags(dt.m_moreFlags),
+                  m_comment(dt.m_comment),
+                  m_validity(dt.m_validity),
+                  m_lineNum(dt.m_lineNum),
+                  m_errorString(dt.m_errorString),
+                  m_bookmark(dt.m_bookmark) {}
+
+        /// Returns the original string.
+        const wxString& GetString() const { return m_string; }
+
+        /// Does this entry have a msgid_plural?
+        const bool HasPlural() const { return m_hasPlural; }
+
+        /// Returns the plural string.
+        const wxString& GetPluralString() const { return m_plural; }
+
+        /// Does this entry have a msgctxt?
+        const bool HasContext() const { return m_hasContext; }
+
+        /// Returns context string (can only be called if HasContext() returns
+        /// true and empty string is accepted value).
+        const wxString& GetContext() const { return m_context; }
+
+        /// How many translations (plural forms) do we have?
+        size_t GetNumberOfTranslations() const
+            { return m_translations.GetCount(); }
+
+        /// Returns the nth-translation.
+        wxString GetTranslation(unsigned n = 0) const;
+
+        /// Returns array of all occurences of this string in source code.
+        const wxArrayString& GetReferences() const { return m_references; }
+
+        /// Returns comment added by the translator to this entry
+        const wxString& GetComment() const { return m_comment; }
+
+        /// Returns array of all auto comments.
+        const wxArrayString& GetAutoComments() const { return m_autocomments; }
+
+        /// Convenience function: does this entry has a comment?
+        const bool HasComment() const { return !m_comment.empty(); }
+
+        /// Adds new reference to the entry (used by SourceDigger).
+        void AddReference(const wxString& ref)
+        {
+            if (m_references.Index(ref) == wxNOT_FOUND)
+                m_references.Add(ref);
+        }
+
+        /// Clears references (used by SourceDigger).
+        void ClearReferences()
+        {
+            m_references.Clear();
+        }
+
+        /// Sets the string.
+        void SetString(const wxString& s)
+        {
+            m_string = s;
+            m_validity = Val_Unknown;
+        }
+
+        /// Sets the plural form (if applicable).
+        void SetPluralString(const wxString& p)
+        {
+            m_plural = p;
+            m_hasPlural = true;
+        }
+
+        /// Sets the context (msgctxt0
+        void SetContext(const wxString& context)
+        {
+            m_hasContext = true;
+            m_context = context;
+        }
+
+        /** Sets the translation. Changes "translated" status to true
+            if \a t is not empty.
+         */
+        void SetTranslation(const wxString& t, unsigned index = 0);
+
+        /// Sets all translations.
+        void SetTranslations(const wxArrayString& t);
+
+        /// Sets the comment.
+        void SetComment(const wxString& c)
+        {
+            m_comment = c;
+        }
+
+        /** Sets gettext flags directly in string format. It may be
+            either empty string or "#, fuzzy", "#, c-format",
+            "#, fuzzy, c-format" or others (not understood by Poedit).
+         */
+        void SetFlags(const wxString& flags);
+
+        /// Gets gettext flags. \see SetFlags
+        wxString GetFlags() const;
+
+        /// Sets fuzzy flag.
+        void SetFuzzy(bool fuzzy) { m_isFuzzy = fuzzy; }
+        /// Gets value of fuzzy flag.
+        bool IsFuzzy() const { return m_isFuzzy; }
+        /// Sets translated flag.
+        void SetTranslated(bool t) { m_isTranslated = t; }
+        /// Gets value of translated flag.
+        bool IsTranslated() const { return m_isTranslated; }
+        /// Sets modified flag.
+        void SetModified(bool modified) { m_isModified = modified; }
+        /// Gets value of modified flag.
+        bool IsModified() const { return m_isModified; }
+        /// Sets automatic translation flag.
+        void SetAutomatic(bool automatic) { m_isAutomatic = automatic; }
+        /// Gets value of automatic translation flag.
+        bool IsAutomatic() const { return m_isAutomatic; }
+        /// Sets the number of the line this entry occurs on.
+        void SetLineNumber(unsigned line) { m_lineNum = line; }
+        /// Get line number of this entry.
+        unsigned GetLineNumber() const { return m_lineNum; }
+
+        /** Returns true if the gettext flags line contains "foo-format"
+            flag when called with "foo" as argument. */
+        bool IsInFormat(const wxString& format);
+
+        /// Adds new autocomments (#. )
+        void AddAutoComments(const wxString& com)
+        {
+            m_autocomments.Add(com);
+        }
+
+        /// Clears autocomments.
+        void ClearAutoComments()
+        {
+            m_autocomments.Clear();
+        }
+
+        void SetOldMsgid(const wxArrayString& data) { m_oldMsgid = data; }
+        const wxArrayString& GetOldMsgid() const { return m_oldMsgid; }
+
+        // Validity (syntax-checking) status of the entry:
+        enum Validity
+        {
+            Val_Unknown = -1,
+            Val_Invalid = 0,
+            Val_Valid = 1
+        };
+
+        /** Checks if %i etc. are correct in the translation (true if yes).
+            Strings that are not c-format are always correct. */
+        Validity GetValidity() const { return m_validity; }
+        void SetValidity(bool val)
+            { m_validity = val ? Val_Valid : Val_Invalid; }
+
+        void SetErrorString(const wxString& str) { m_errorString = str; }
+        wxString GetErrorString() const { return m_errorString; }
+
+        /// Returns the bookmark for the item
+        Bookmark GetBookmark() {return m_bookmark;}
+        /// Returns true if the item has a bookmark
+        bool HasBookmark() {return (GetBookmark() != NO_BOOKMARK);}
+        /// Sets the bookmark
+        void SetBookmark(Bookmark bookmark) {m_bookmark = bookmark;}
+
+    private:
+        wxString m_string, m_plural;
+        bool m_hasPlural;
+
+        bool m_hasContext;
+        wxString m_context;
+
+        wxArrayString m_translations;
+
+        wxArrayString m_references, m_autocomments;
+        wxArrayString m_oldMsgid;
+        bool m_isFuzzy, m_isTranslated, m_isModified, m_isAutomatic;
+        bool m_hasBadTokens;
+        wxString m_moreFlags;
+        wxString m_comment;
+        Validity m_validity;
+        unsigned m_lineNum;
+        wxString m_errorString;
+        Bookmark m_bookmark;
+};
+
+/** This class holds information about one particular deleted item.
+    This includes deleted lines, references, translation's status
+    (fuzzy, non translated, translated) and optional comment(s).
+
+    This class is mostly internal, used by Catalog to store data.
+ */
+// FIXME: derive this from CatalogData (or CatalogDataBase)
+class CatalogDeletedData
+{
+    public:
+        /// Ctor.
+        CatalogDeletedData()
+                : m_lineNum(0) {}
+        CatalogDeletedData(const wxArrayString& deletedLines)
+                : m_deletedLines(deletedLines),
+                  m_lineNum(0) {}
+
+        CatalogDeletedData(const CatalogDeletedData& dt)
+                : m_deletedLines(dt.m_deletedLines),
+                  m_references(dt.m_references),
+                  m_autocomments(dt.m_autocomments),
+                  m_flags(dt.m_flags),
+                  m_comment(dt.m_comment),
+                  m_lineNum(dt.m_lineNum) {}
+
+        /// Returns the deleted lines.
+        const wxArrayString& GetDeletedLines() const { return m_deletedLines; }
+
+        /// Returns array of all occurences of this string in source code.
+        const wxArrayString& GetReferences() const { return m_references; }
+
+        /// Returns comment added by the translator to this entry
+        const wxString& GetComment() const { return m_comment; }
+
+        /// Returns array of all auto comments.
+        const wxArrayString& GetAutoComments() const { return m_autocomments; }
+
+        /// Convenience function: does this entry has a comment?
+        const bool HasComment() const { return !m_comment.empty(); }
+
+        /// Adds new reference to the entry (used by SourceDigger).
+        void AddReference(const wxString& ref)
+        {
+            if (m_references.Index(ref) == wxNOT_FOUND)
+                m_references.Add(ref);
+        }
+
+        /// Clears references (used by SourceDigger).
+        void ClearReferences()
+        {
+            m_references.Clear();
+        }
+
+        /// Sets the string.
+        void SetDeletedLines(const wxArrayString& a)
+        {
+            m_deletedLines = a;
+        }
+
+        /// Sets the comment.
+        void SetComment(const wxString& c)
+        {
+            m_comment = c;
+        }
+
+        /** Sets gettext flags directly in string format. It may be
+            either empty string or "#, fuzzy", "#, c-format",
+            "#, fuzzy, c-format" or others (not understood by Poedit).
+         */
+        void SetFlags(const wxString& flags) {m_flags = flags;};
+
+        /// Gets gettext flags. \see SetFlags
+        wxString GetFlags() const {return m_flags;};
+
+        /// Sets the number of the line this entry occurs on.
+        void SetLineNumber(unsigned line) { m_lineNum = line; }
+        /// Get line number of this entry.
+        unsigned GetLineNumber() const { return m_lineNum; }
+
+        /// Adds new autocomments (#. )
+        void AddAutoComments(const wxString& com)
+        {
+            m_autocomments.Add(com);
+        }
+
+        /// Clears autocomments.
+        void ClearAutoComments()
+        {
+            m_autocomments.Clear();
+        }
+
+    private:
+        wxArrayString m_deletedLines;
+
+        wxArrayString m_references, m_autocomments;
+        wxString m_flags;
+        wxString m_comment;
+        unsigned m_lineNum;
+};
+
+
+typedef std::vector<CatalogData> CatalogDataArray;
+typedef std::vector<CatalogDeletedData> CatalogDeletedDataArray;
+typedef std::map<wxString, unsigned> CatalogDataIndex;
+
 /** This class stores all translations, together with filelists, references
     and other additional information. It can read .po files and save both
     .mo and .po files. Furthermore, it provides facilities for updating the
@@ -175,19 +500,8 @@ class Catalog
          */
         bool UpdateFromPOT(const wxString& pot_file, bool summary = true);
 
-        /** Adds translation into the catalog.
-            \return true on success or false if such key does
-                     not exist in the catalog
-         */
-        bool Translate(const wxString& key, const wxString& translation);
-
-        /** Returns pointer to catalog item with key \a key or NULL if
-            such key is not available.
-         */
-        CatalogData* FindItem(const wxString& key) const;
-
         /// Returns the number of strings/translations in the catalog.
-        size_t GetCount() const { return m_count; }
+        size_t GetCount() const { return m_items.size(); }
 
         /** Returns number of all, fuzzy, badtokens and untranslated items.
             Any argument may be NULL if the caller is not interested in
@@ -196,10 +510,10 @@ class Catalog
         void GetStatistics(int *all, int *fuzzy, int *badtokens, int *untranslated);
 
         /// Gets n-th item in the catalog (read-write access).
-        CatalogData& operator[](unsigned n) { return m_dataArray[n]; }
+        CatalogData& operator[](unsigned n) { return m_items[n]; }
 
         /// Gets n-th item in the catalog (read-only access).
-        const CatalogData& operator[](unsigned n) const { return m_dataArray[n]; }
+        const CatalogData& operator[](unsigned n) const { return m_items[n]; }
 
         /// Gets catalog header (read-write access).
         HeaderData& Header() { return m_header; }
@@ -213,21 +527,18 @@ class Catalog
          */
         bool IsOk() const { return m_isOk; }
 
-        /// Appends content of \cat to this catalog.
-        void Append(Catalog& cat);
-
-        /** Returns xx_YY ISO code of catalog's language if either the poEdit
+        /** Returns xx_YY ISO code of catalog's language if either the Poedit
             extensions headers are present or if filename is known and is in
             the xx[_YY] form, otherwise returns empty string. */
         wxString GetLocaleCode() const;
 
         /// Adds entry to the catalog (the catalog will take ownership of
         /// the object).
-        void AddItem(CatalogData *data);
+        void AddItem(const CatalogData& data);
 
         /// Adds entry to the catalog (the catalog will take ownership of
         /// the object).
-        void AddDeletedItem(CatalogDeletedData *data);
+        void AddDeletedItem(const CatalogDeletedData& data);
 
         /// Returns true if the catalog contains obsolete entries (~.*)
         bool HasDeletedItems();
@@ -273,10 +584,9 @@ class Catalog
         bool ShowMergeSummary(Catalog *refcat);
 
     private:
-        wxHashTable *m_data;
-        CatalogDataArray m_dataArray;
-        CatalogDeletedDataArray m_deletedItemsArray;
-        unsigned m_count; // no. of items
+        CatalogDataArray m_items;
+        CatalogDeletedDataArray m_deletedItems;
+
         bool m_isOk;
         wxString m_fileName;
         HeaderData m_header;
@@ -307,11 +617,14 @@ class CatalogParser
         virtual bool OnEntry(const wxString& msgid,
                              const wxString& msgid_plural,
                              bool has_plural,
+                             bool has_context,
+                             const wxString& context,
                              const wxArrayString& mtranslations,
                              const wxString& flags,
                              const wxArrayString& references,
                              const wxString& comment,
                              const wxArrayString& autocomments,
+                             const wxArrayString& msgid_old,
                              unsigned lineNumber) = 0;
 
         /** Called when new deleted entry was parsed. Parsing continues
@@ -332,306 +645,4 @@ class CatalogParser
         wxTextFile *m_textFile;
 };
 
-/** This class holds information about one particular string.
-    This includes original string and its occurences in source code
-    (so-called references), translation and translation's status
-    (fuzzy, non translated, translated) and optional comment.
-
-    This class is mostly internal, used by Catalog to store data.
- */
-class CatalogData : public wxObject
-{
-    public:
-        /// Ctor. Initializes the object with original string and translation.
-        CatalogData(const wxString& str, const wxString& str_plural)
-                : wxObject(),
-                  m_string(str),
-                  m_plural(str_plural),
-                  m_hasPlural(false),
-                  m_references(),
-                  m_isFuzzy(false),
-                  m_isTranslated(false),
-                  m_isModified(false),
-                  m_isAutomatic(false),
-                  m_validity(Val_Unknown),
-                  m_lineNum(0),
-                  m_bookmark(NO_BOOKMARK) {}
-
-        CatalogData(const CatalogData& dt)
-                : wxObject(),
-                  m_string(dt.m_string),
-                  m_plural(dt.m_plural),
-                  m_hasPlural(dt.m_hasPlural),
-                  m_translations(dt.m_translations),
-                  m_references(dt.m_references),
-                  m_autocomments(dt.m_autocomments),
-                  m_isFuzzy(dt.m_isFuzzy),
-                  m_isTranslated(dt.m_isTranslated),
-                  m_isModified(dt.m_isModified),
-                  m_isAutomatic(dt.m_isAutomatic),
-                  m_hasBadTokens(dt.m_hasBadTokens),
-                  m_moreFlags(dt.m_moreFlags),
-                  m_comment(dt.m_comment),
-                  m_validity(dt.m_validity),
-                  m_lineNum(dt.m_lineNum),
-                  m_errorString(dt.m_errorString),
-                  m_bookmark(dt.m_bookmark) {}
-
-        /// Returns the original string.
-        const wxString& GetString() const { return m_string; }
-
-        /// Does this entry have a msgid_plural?
-        const bool HasPlural() const { return m_hasPlural; }
-
-        /// Returns the plural string.
-        const wxString& GetPluralString() const { return m_plural; }
-
-        /// How many translations (plural forms) do we have?
-        size_t GetNumberOfTranslations() const
-            { return m_translations.GetCount(); }
-
-        /// Returns the nth-translation.
-        wxString GetTranslation(unsigned n = 0) const;
-
-        /// Returns array of all occurences of this string in source code.
-        const wxArrayString& GetReferences() const { return m_references; }
-
-        /// Returns comment added by the translator to this entry
-        const wxString& GetComment() const { return m_comment; }
-
-        /// Returns array of all auto comments.
-        const wxArrayString& GetAutoComments() const { return m_autocomments; }
-
-        /// Convenience function: does this entry has a comment?
-        const bool HasComment() const { return !m_comment.empty(); }
-
-        /// Adds new reference to the entry (used by SourceDigger).
-        void AddReference(const wxString& ref)
-        {
-            if (m_references.Index(ref) == wxNOT_FOUND)
-                m_references.Add(ref);
-        }
-
-        /// Clears references (used by SourceDigger).
-        void ClearReferences()
-        {
-            m_references.Clear();
-        }
-
-        /// Sets the string.
-        void SetString(const wxString& s)
-        {
-            m_string = s;
-            m_validity = Val_Unknown;
-        }
-
-        /// Sets the plural form (if applicable).
-        void SetPluralString(const wxString& p)
-        {
-            m_plural = p;
-            m_hasPlural = true;
-        }
-
-        /** Sets the translation. Changes "translated" status to true
-            if \a t is not empty.
-         */
-        void SetTranslation(const wxString& t, unsigned index = 0);
-
-        /// Sets all translations.
-        void SetTranslations(const wxArrayString& t);
-
-        /// Sets the comment.
-        void SetComment(const wxString& c)
-        {
-            m_comment = c;
-        }
-
-        /** Sets gettext flags directly in string format. It may be
-            either empty string or "#, fuzzy", "#, c-format",
-            "#, fuzzy, c-format" or others (not understood by poEdit).
-         */
-        void SetFlags(const wxString& flags);
-
-        /// Gets gettext flags. \see SetFlags
-        wxString GetFlags() const;
-
-        /// Sets fuzzy flag.
-        void SetFuzzy(bool fuzzy) { m_isFuzzy = fuzzy; }
-        /// Gets value of fuzzy flag.
-        bool IsFuzzy() const { return m_isFuzzy; }
-        /// Sets translated flag.
-        void SetTranslated(bool t) { m_isTranslated = t; }
-        /// Gets value of translated flag.
-        bool IsTranslated() const { return m_isTranslated; }
-        /// Sets modified flag.
-        void SetModified(bool modified) { m_isModified = modified; }
-        /// Gets value of modified flag.
-        bool IsModified() const { return m_isModified; }
-        /// Sets automatic translation flag.
-        void SetAutomatic(bool automatic) { m_isAutomatic = automatic; }
-        /// Gets value of automatic translation flag.
-        bool IsAutomatic() const { return m_isAutomatic; }
-        /// Sets the number of the line this entry occurs on.
-        void SetLineNumber(unsigned line) { m_lineNum = line; }
-        /// Get line number of this entry.
-        unsigned GetLineNumber() const { return m_lineNum; }
-
-        /** Returns true if the gettext flags line contains "foo-format"
-            flag when called with "foo" as argument. */
-        bool IsInFormat(const wxString& format);
-
-        /// Adds new autocomments (#. )
-        void AddAutoComments(const wxString& com)
-        {
-            m_autocomments.Add(com);
-        }
-
-        /// Clears autocomments.
-        void ClearAutoComments()
-        {
-            m_autocomments.Clear();
-        }
-
-        // Validity (syntax-checking) status of the entry:
-        enum Validity
-        {
-            Val_Unknown = -1,
-            Val_Invalid = 0,
-            Val_Valid = 1
-        };
-
-        /** Checks if %i etc. are correct in the translation (true if yes).
-            Strings that are not c-format are always correct. */
-        Validity GetValidity() const { return m_validity; }
-        void SetValidity(bool val)
-            { m_validity = val ? Val_Valid : Val_Invalid; }
-
-        void SetErrorString(const wxString& str) { m_errorString = str; }
-        wxString GetErrorString() const { return m_errorString; }
-
-        /// Returns the bookmark for the item
-        Bookmark GetBookmark() {return m_bookmark;}
-        /// Returns true if the item has a bookmark
-        bool HasBookmark() {return (GetBookmark() != NO_BOOKMARK);}
-
-    private:
-        wxString m_string, m_plural;
-        bool m_hasPlural;
-        wxArrayString m_translations;
-
-        wxArrayString m_references, m_autocomments;
-        bool m_isFuzzy, m_isTranslated, m_isModified, m_isAutomatic;
-        bool m_hasBadTokens;
-        wxString m_moreFlags;
-        wxString m_comment;
-        Validity m_validity;
-        unsigned m_lineNum;
-        wxString m_errorString;
-        Bookmark m_bookmark;
-
-        /// Sets the bookmark
-        void SetBookmark(Bookmark bookmark) {m_bookmark = bookmark;}
-
-   friend class Catalog;
-};
-
-/** This class holds information about one particular deleted item.
-    This includes deleted lines, references, translation's status
-    (fuzzy, non translated, translated) and optional comment(s).
-
-    This class is mostly internal, used by Catalog to store data.
- */
-class CatalogDeletedData : public wxObject
-{
-    public:
-        /// Ctor. Initializes the object with original string and translation.
-        CatalogDeletedData(const wxArrayString& deletedLines)
-                : wxObject(),
-                  m_deletedLines(deletedLines),
-                  m_lineNum(0) {}
-
-        CatalogDeletedData(const CatalogDeletedData& dt)
-                : wxObject(),
-                  m_deletedLines(dt.m_deletedLines),
-                  m_references(dt.m_references),
-                  m_autocomments(dt.m_autocomments),
-                  m_flags(dt.m_flags),
-                  m_comment(dt.m_comment),
-                  m_lineNum(dt.m_lineNum) {}
-
-        /// Returns the deleted lines.
-        const wxArrayString& GetDeletedLines() const { return m_deletedLines; }
-
-        /// Returns array of all occurences of this string in source code.
-        const wxArrayString& GetReferences() const { return m_references; }
-
-        /// Returns comment added by the translator to this entry
-        const wxString& GetComment() const { return m_comment; }
-
-        /// Returns array of all auto comments.
-        const wxArrayString& GetAutoComments() const { return m_autocomments; }
-
-        /// Convenience function: does this entry has a comment?
-        const bool HasComment() const { return !m_comment.empty(); }
-
-        /// Adds new reference to the entry (used by SourceDigger).
-        void AddReference(const wxString& ref)
-        {
-            if (m_references.Index(ref) == wxNOT_FOUND)
-                m_references.Add(ref);
-        }
-
-        /// Clears references (used by SourceDigger).
-        void ClearReferences()
-        {
-            m_references.Clear();
-        }
-
-        /// Sets the string.
-        void SetDeletedLines(const wxArrayString& a)
-        {
-            m_deletedLines = a;
-        }
-
-        /// Sets the comment.
-        void SetComment(const wxString& c)
-        {
-            m_comment = c;
-        }
-
-        /** Sets gettext flags directly in string format. It may be
-            either empty string or "#, fuzzy", "#, c-format",
-            "#, fuzzy, c-format" or others (not understood by poEdit).
-         */
-        void SetFlags(const wxString& flags) {m_flags = flags;};
-
-        /// Gets gettext flags. \see SetFlags
-        wxString GetFlags() const {return m_flags;};
-
-        /// Sets the number of the line this entry occurs on.
-        void SetLineNumber(unsigned line) { m_lineNum = line; }
-        /// Get line number of this entry.
-        unsigned GetLineNumber() const { return m_lineNum; }
-
-        /// Adds new autocomments (#. )
-        void AddAutoComments(const wxString& com)
-        {
-            m_autocomments.Add(com);
-        }
-
-        /// Clears autocomments.
-        void ClearAutoComments()
-        {
-            m_autocomments.Clear();
-        }
-
-    private:
-        wxArrayString m_deletedLines;
-
-        wxArrayString m_references, m_autocomments;
-        wxString m_flags;
-        wxString m_comment;
-        unsigned m_lineNum;
-};
-
 #endif // _CATALOG_H_
