@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2003-2006 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: chooselang.cpp 1066 2007-03-21 17:27:08Z vaclavslavik $
+ *  $Id: chooselang.cpp 1216 2007-11-24 10:25:15Z vaclavslavik $
  *
  *  Language chooser
  *
@@ -118,6 +118,7 @@ wxLanguage ChooseLanguage()
         { _T("Hungarian"), wxLANGUAGE_HUNGARIAN },
         { _T("Icelandic"), wxLANGUAGE_ICELANDIC },
         { _T("Indonesian"), wxLANGUAGE_INDONESIAN },
+        { _T("Irish"), wxLANGUAGE_IRISH },
         { _T("Italian"), wxLANGUAGE_ITALIAN },
         { _T("Japanese"), wxLANGUAGE_JAPANESE },
         { _T("Korean"), wxLANGUAGE_KOREAN },
@@ -172,8 +173,8 @@ void ChangeUILanguage()
     if (lang == wxLANGUAGE_UNKNOWN)
         return;
     SaveUILanguage(lang);
-    wxMessageBox(_("You must restart poEdit for this change to take effect."),
-                 _T("poEdit"),
+    wxMessageBox(_("You must restart Poedit for this change to take effect."),
+                 _T("Poedit"),
                  wxOK | wxCENTRE | wxICON_INFORMATION);
 }
 
