@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2007 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edapp.cpp 1116 2007-06-16 20:56:34Z vaclavslavik $
+ *  $Id: edapp.cpp 1253 2007-12-11 11:19:00Z vaclavslavik $
  *
  *  Application class
  *
@@ -38,9 +38,15 @@
 #include <wx/xrc/xmlres.h>
 #include <wx/xrc/xh_all.h>
 #include <wx/stdpaths.h>
+#include <wx/filename.h>
+#include <wx/sysopt.h>
+
+#ifdef USE_SPARKLE
+#include <Sparkle/SUCarbonAPI.h>
+#endif // USE_SPARKLE
 
 #if !wxUSE_UNICODE
-    #error "Unicode build of wxWidgets is required by poEdit"
+    #error "Unicode build of wxWidgets is required by Poedit"
 #endif
 
 #include "edapp.h"
@@ -52,9 +58,9 @@
 #include "icons.h"
 
 
-IMPLEMENT_APP(poEditApp);
+IMPLEMENT_APP(PoeditApp);
 
-wxString poEditApp::GetAppPath() const
+wxString PoeditApp::GetAppPath() const
 {
 #if defined(__UNIX__)
     wxString home;
@@ -62,23 +68,20 @@ wxString poEditApp::GetAppPath() const
         home = wxString::FromAscii(POEDIT_PREFIX);
     return home;
 #elif defined(__WXMSW__)
-    wxString regkey;
-    regkey.Printf(_T("%s/application_path"), GetAppVersion().c_str());
-    wxString path = wxConfigBase::Get()->Read(regkey, wxEmptyString);
-    if (!path)
-    {
-        wxLogError(_("poEdit installation is broken, cannot find application's home directory."));
-        path = _T(".");
-    }
-    return path;
+    wxString exedir;
+    wxFileName::SplitPath(wxStandardPaths::Get().GetExecutablePath(),
+                          &exedir, NULL, NULL);
+    wxFileName fn = wxFileName::DirName(exedir);
+    fn.RemoveLastDir();
+    return fn.GetFullPath();
 #else
 #error "Unsupported platform!"
 #endif
 }
 
-wxString poEditApp::GetAppVersion() const
+wxString PoeditApp::GetAppVersion() const
 {
-    wxString version(_T("1.3.7"));
+    wxString version(_T("1.3.9"));
     return version;
 }
 
@@ -89,16 +92,20 @@ static wxArrayString gs_filesToOpen;
 
 extern void InitXmlResource();
 
-bool poEditApp::OnInit()
+bool PoeditApp::OnInit()
 {
     if (!wxApp::OnInit())
         return false;
 
+#ifdef __WXMAC__
+    wxSystemOptions::SetOption(wxMAC_TEXTCONTROL_USE_SPELL_CHECKER, 1);
+#endif
+
 #if defined(__UNIX__) && !defined(__WXMAC__)
     wxString home = wxGetHomeDir() + _T("/");
 
-    // create poEdit cfg dir, move ~/.poedit to ~/.poedit/config
-    // (upgrade from older versions of poEdit which used ~/.poedit file)
+    // create Poedit cfg dir, move ~/.poedit to ~/.poedit/config
+    // (upgrade from older versions of Poedit which used ~/.poedit file)
     if (!wxDirExists(home + _T(".poedit")))
     {
         if (wxFileExists(home + _T(".poedit")))
@@ -110,7 +117,7 @@ bool poEditApp::OnInit()
 #endif
 
     SetVendorName(_T("Vaclav Slavik"));
-    SetAppName(_T("poedit"));
+    SetAppName(_T("Poedit"));
 
 #if defined(__WXMAC__)
     #define CFG_FILE (wxStandardPaths::Get().GetUserConfigDir() + _T("/net.poedit.Poedit.cfg"))
@@ -134,18 +141,6 @@ bool poEditApp::OnInit()
                      wxCONFIG_USE_GLOBAL_FILE | wxCONFIG_USE_LOCAL_FILE));
     wxConfigBase::Get()->SetExpandEnvVars(false);
 
-#ifdef __WXMAC__
-    wxLocale::AddCatalogLookupPathPrefix(
-        wxStandardPaths::Get().GetResourcesDir() + _T("/locale"));
-#else
-    wxLocale::AddCatalogLookupPathPrefix(GetAppPath() + _T("/share/locale"));
-#endif
-
-    m_locale.Init(GetUILanguage());
-    
-    m_locale.AddCatalog(_T("poedit"));
-    m_locale.AddCatalog(_T("poedit-wxstd")); // for semistatic builds
-
     wxImage::AddHandler(new wxGIFHandler);
     wxImage::AddHandler(new wxPNGHandler);
     wxXmlResource::Get()->InitAllHandlers();
@@ -159,9 +154,20 @@ bool poEditApp::OnInit()
     wxArtProvider::PushProvider(new PoeditArtProvider);
 #endif
 
+#ifdef __WXMAC__
+    wxLocale::AddCatalogLookupPathPrefix(
+        wxStandardPaths::Get().GetResourcesDir() + _T("/locale"));
+#else
+    wxLocale::AddCatalogLookupPathPrefix(GetAppPath() + _T("/share/locale"));
+#endif
+
+    m_locale.Init(GetUILanguage());
+    
+    m_locale.AddCatalog(_T("poedit"));
+
     if (wxConfig::Get()->Read(_T("translator_name"), _T("nothing")) == _T("nothing"))
     {
-        wxMessageBox(_("This is first time you run poEdit.\nPlease fill in your name and e-mail address.\n(This information is used only in catalogs headers)"), _("Setup"),
+        wxMessageBox(_("This is first time you run Poedit.\nPlease fill in your name and e-mail address.\n(This information is used only in catalogs headers)"), _("Setup"),
                        wxOK | wxICON_INFORMATION);
 
         PreferencesDialog dlg;
@@ -185,24 +191,28 @@ bool poEditApp::OnInit()
     }
 #endif // !__WXMAC__
 
+#ifdef USE_SPARKLE
+    SUSparkleInitializeForCarbon();
+#endif // USE_SPARKLE
+
     return true;
 }
 
 
-void poEditApp::OpenNewFile()
+void PoeditApp::OpenNewFile()
 {
     if (wxConfig::Get()->Read(_T("manager_startup"), (long)false))
         ManagerFrame::Create()->Show(true);
     else
-        poEditFrame::Create(wxEmptyString);
+        PoeditFrame::Create(wxEmptyString);
 }
 
-void poEditApp::OpenFile(const wxString& name)
+void PoeditApp::OpenFile(const wxString& name)
 {
-    poEditFrame::Create(name);
+    PoeditFrame::Create(name);
 }
 
-void poEditApp::SetDefaultParsers(wxConfigBase *cfg)
+void PoeditApp::SetDefaultParsers(wxConfigBase *cfg)
 {
     ParsersDB pdb;
     bool changed = false;
@@ -248,7 +258,7 @@ void poEditApp::SetDefaultParsers(wxConfigBase *cfg)
         changed = true;
     }
 
-    // If upgrading poEdit to 1.2.4, add dxgettext parser for Delphi:
+    // If upgrading Poedit to 1.2.4, add dxgettext parser for Delphi:
 #ifdef __WINDOWS__
     if (defaultsVersion == _T("1.2.x"))
     {
@@ -263,7 +273,7 @@ void poEditApp::SetDefaultParsers(wxConfigBase *cfg)
     }
 #endif
 
-    // If upgrading poEdit to 1.2.5, update C++ parser to handle --from-code:
+    // If upgrading Poedit to 1.2.5, update C++ parser to handle --from-code:
     if (defaultsVersion == _T("1.2.x") || defaultsVersion == _T("1.2.4"))
     {
         int cpp = pdb.FindParser(_T("C/C++"));
@@ -285,7 +295,7 @@ void poEditApp::SetDefaultParsers(wxConfigBase *cfg)
     }
 }
 
-void poEditApp::SetDefaultCfg(wxConfigBase *cfg)
+void PoeditApp::SetDefaultCfg(wxConfigBase *cfg)
 {
     SetDefaultParsers(cfg);
 
@@ -299,13 +309,7 @@ void poEditApp::SetDefaultCfg(wxConfigBase *cfg)
 #elif defined(__UNIX__)
         dbpath = wxGetHomeDir() + _T("/.poedit/tm");
 #elif defined(__WXMSW__)
-        // VS: this distinguishes between NT and Win9X systems -- the former
-        //     has users' home directories while on the latter wxGetHomeDir
-        //     will return path of the executable
-        if (wxGetHomeDir().IsSameAs(GetAppPath() + _T("\\bin"), false))      
-            dbpath = GetAppPath() + _T("\\share\\poedit\\tm");
-        else
-            dbpath = wxGetHomeDir() + _T("\\poedit_tm");
+        dbpath = wxGetHomeDir() + _T("\\poedit_tm");
 #endif
         cfg->Write(_T("TM/database_path"), dbpath);
     }
@@ -324,14 +328,14 @@ void poEditApp::SetDefaultCfg(wxConfigBase *cfg)
     cfg->Write(_T("version"), GetAppVersion());
 }
 
-void poEditApp::OnInitCmdLine(wxCmdLineParser& parser)
+void PoeditApp::OnInitCmdLine(wxCmdLineParser& parser)
 {
     wxApp::OnInitCmdLine(parser);
     parser.AddParam(_T("catalog.po"), wxCMD_LINE_VAL_STRING, 
                     wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_PARAM_MULTIPLE);
 }
 
-bool poEditApp::OnCmdLineParsed(wxCmdLineParser& parser)
+bool PoeditApp::OnCmdLineParsed(wxCmdLineParser& parser)
 {
     if (!wxApp::OnCmdLineParsed(parser))
         return false;
