@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2007 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.cpp 1115 2007-06-16 20:42:22Z vaclavslavik $
+ *  $Id: edlistctrl.cpp 1248 2007-12-09 13:25:08Z vaclavslavik $
  *
  *  List view control
  *
@@ -37,7 +37,7 @@
 #include "edlistctrl.h"
 #include "digits.h"
 
-// I don't like this global flag, but all poEditFrame instances should share it :(
+// I don't like this global flag, but all PoeditFrame instances should share it :(
 bool gs_shadedList = false;
 
 // colours used in the list:
@@ -72,8 +72,8 @@ enum
     IMG_BK9       = 10 << 3
 };
 
-BEGIN_EVENT_TABLE(poEditListCtrl, wxListCtrl)
-   EVT_SIZE(poEditListCtrl::OnSize)
+BEGIN_EVENT_TABLE(PoeditListCtrl, wxListCtrl)
+   EVT_SIZE(PoeditListCtrl::OnSize)
 END_EVENT_TABLE()
 
 
@@ -140,7 +140,7 @@ wxBitmap BitmapFromList(wxImageList* list, int index)
     return bmp;
 }
 
-poEditListCtrl::poEditListCtrl(wxWindow *parent,
+PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
                wxWindowID id,
                const wxPoint &pos,
                const wxSize &size,
@@ -201,22 +201,27 @@ poEditListCtrl::poEditListCtrl(wxWindow *parent,
     m_attrInvalid[1].SetBackgroundColour(g_ItemColourInvalid[1]);
 }
 
-poEditListCtrl::~poEditListCtrl()
+PoeditListCtrl::~PoeditListCtrl()
 {
 }
 
-void poEditListCtrl::CreateColumns()
+void PoeditListCtrl::SetDisplayLines(bool dl)
 {
-    ClearAll();
+    m_displayLines = dl;
+    CreateColumns();
+}
+
+void PoeditListCtrl::CreateColumns()
+{
+    DeleteAllColumns();
     InsertColumn(0, _("Original string"));
     InsertColumn(1, _("Translation"));
     if (m_displayLines)
         InsertColumn(2, _("Line"), wxLIST_FORMAT_RIGHT);
-    ReadCatalog();
     SizeColumns();
 }
 
-void poEditListCtrl::SizeColumns()
+void PoeditListCtrl::SizeColumns()
 {
     const int LINE_COL_SIZE = m_displayLines ? 50 : 0;
 
@@ -232,13 +237,23 @@ void poEditListCtrl::SizeColumns()
 }
 
 
-void poEditListCtrl::CatalogChanged(Catalog* catalog)
+void PoeditListCtrl::CatalogChanged(Catalog* catalog)
 {
+    Freeze();
+
+    // this is to prevent crashes (wxMac at least) when shortening virtual
+    // listctrl when its scrolled to the bottom:
+    m_catalog = NULL;
+    SetItemCount(0);
+
+    // now read the new catalog:
     m_catalog = catalog;
     ReadCatalog();
+
+    Thaw();
 }
 
-void poEditListCtrl::ReadCatalog()
+void PoeditListCtrl::ReadCatalog()
 {
     if (m_catalog == NULL)
     {
@@ -246,9 +261,6 @@ void poEditListCtrl::ReadCatalog()
         return;
     }
 
-    // set the item count
-    SetItemCount(m_catalog->GetCount());
-
     // create the lookup arrays of Ids by first splitting it upon
     // four categories of items:
     // unstranslated, invalid, fuzzy and the rest
@@ -297,9 +309,17 @@ void poEditListCtrl::ReadCatalog()
         m_itemIndexToCatalogIndexArray.push_back(restIds[i]);
         m_catalogIndexToItemIndexArray[restIds[i]] = listItemId++;
     }
+
+
+    // now that everything is prepared, we may set the item count
+    SetItemCount(m_catalog->GetCount());
+
+    // scroll to the top and refresh everything:
+    Select(0);
+    RefreshItems(0, m_catalog->GetCount());
 }
 
-wxString poEditListCtrl::OnGetItemText(long item, long column) const
+wxString PoeditListCtrl::OnGetItemText(long item, long column) const
 {
     if (m_catalog == NULL)
         return wxEmptyString;
@@ -325,7 +345,7 @@ wxString poEditListCtrl::OnGetItemText(long item, long column) const
     }
 }
 
-wxListItemAttr *poEditListCtrl::OnGetItemAttr(long item) const
+wxListItemAttr *PoeditListCtrl::OnGetItemAttr(long item) const
 {
     size_t idx = gs_shadedList ? size_t(item % 2) : 0;
 
@@ -344,7 +364,7 @@ wxListItemAttr *poEditListCtrl::OnGetItemAttr(long item) const
         return (wxListItemAttr*)&m_attrNormal[idx];
 }
 
-int poEditListCtrl::OnGetItemImage(long item) const
+int PoeditListCtrl::OnGetItemImage(long item) const
 {
     if (m_catalog == NULL)
         return IMG_NOTHING;
@@ -364,23 +384,27 @@ int poEditListCtrl::OnGetItemImage(long item) const
     return index;
 }
 
-void poEditListCtrl::OnSize(wxSizeEvent& event)
+void PoeditListCtrl::OnSize(wxSizeEvent& event)
 {
     SizeColumns();
     event.Skip();
 }
 
-long poEditListCtrl::GetIndexInCatalog(long item) const
+long PoeditListCtrl::GetIndexInCatalog(long item) const
 {
-    if (item < (long)m_itemIndexToCatalogIndexArray.size())
+    if (item == -1)
+        return -1;
+    else if (item < (long)m_itemIndexToCatalogIndexArray.size())
         return m_itemIndexToCatalogIndexArray[item];
     else
         return -1;
 }
 
-int poEditListCtrl::GetItemIndex(int catalogIndex) const
+int PoeditListCtrl::GetItemIndex(int catalogIndex) const
 {
-    if (catalogIndex < (int)m_catalogIndexToItemIndexArray.size())
+    if (catalogIndex == -1)
+        return -1;
+    else if (catalogIndex < (int)m_catalogIndexToItemIndexArray.size())
         return m_catalogIndexToItemIndexArray[catalogIndex];
     else
         return -1;
