@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 1999-2005 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
@@ -22,7 +22,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: edlistctrl.h 1066 2007-03-21 17:27:08Z vaclavslavik $
+ *  $Id: edlistctrl.h 1248 2007-12-09 13:25:08Z vaclavslavik $
  *
  *  List view control
  *
@@ -44,10 +44,10 @@ class WXDLLEXPORT wxListEvent;
 extern bool gs_shadedList;
 
 // list control with both columns equally wide:
-class poEditListCtrl : public wxListView
+class PoeditListCtrl : public wxListView
 {
     public:
-        poEditListCtrl(wxWindow *parent,
+        PoeditListCtrl(wxWindow *parent,
                        wxWindowID id = -1,
                        const wxPoint &pos = wxDefaultPosition,
                        const wxSize &size = wxDefaultSize,
@@ -56,13 +56,11 @@ class poEditListCtrl : public wxListView
                        const wxValidator& validator = wxDefaultValidator,
                        const wxString &name = _T("listctrl"));
 
-        virtual ~poEditListCtrl();
-
-        void CreateColumns();
+        virtual ~PoeditListCtrl();
 
         void SizeColumns();
 
-        void SetDisplayLines(bool dl) { m_displayLines = dl; }
+        void SetDisplayLines(bool dl);
 
         // Returns average width of one column in number of characters:
         size_t GetMaxColChars() const
@@ -82,9 +80,26 @@ class poEditListCtrl : public wxListView
         /// Returns the list item index for the given catalog index
         int GetItemIndex(int catalogIndex) const;
 
+        /// Returns current list selection (as list item index)
+        int GetSelection() const { return GetFirstSelected(); }
+
+        /// Returns index of selected catalog item
+        int GetSelectedCatalogItem() const
+        {
+            return GetIndexInCatalog(GetSelection());
+        }
+
+        /// Selects given catalog item
+        void SelectCatalogItem(int catalogIndex)
+        {
+            Select(GetItemIndex(catalogIndex));
+        }
+
     private:
         void OnSize(wxSizeEvent& event);
 
+        void CreateColumns();
+
         void ReadCatalog();
 
         bool m_displayLines;
