@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2003 Christophe Hermier
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: export_html.cpp 1116 2007-06-16 20:56:34Z vaclavslavik $
+ *  $Id: export_html.cpp 1182 2007-11-07 10:31:16Z vaclavslavik $
  *
  *  Catalog export into HTML file
  *
@@ -75,7 +75,7 @@ bool Catalog::ExportToHTML(const wxString& filename)
     f.AddLine(_T("<html>"));
 
     f.AddLine(_T("<head>"));
-	line.Printf(_T("<title> %s - %s / %s - poEdit Export </title>"),
+	line.Printf(_T("<title> %s - %s / %s - Poedit Export </title>"),
                 m_header.Project.c_str(),
                 m_header.Language.c_str(),
                 m_header.Country.c_str());
@@ -153,9 +153,9 @@ bool Catalog::ExportToHTML(const wxString& filename)
 	f.AddLine(_T("</th>"));
 	f.AddLine(_T("</tr>"));
 	
-	for (i = 0; i < m_count; i++)
+	for (i = 0; i < GetCount(); i++)
     {
-        const CatalogData& data = m_dataArray[i];
+        const CatalogData& data = m_items[i];
 
 		wxColour bgcolor = g_ItemColourNormal[i % 2];
 		wxString original_string = data.GetString();
