@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2001-2007 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: findframe.cpp 1115 2007-06-16 20:42:22Z vaclavslavik $
+ *  $Id: findframe.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
  *
  *  Search frame
  *
@@ -52,7 +52,7 @@ BEGIN_EVENT_TABLE(FindFrame, wxFrame)
 END_EVENT_TABLE()
 
 FindFrame::FindFrame(wxWindow *parent,
-                     poEditListCtrl *list,
+                     PoeditListCtrl *list,
                      Catalog *c,
                      wxTextCtrl *textCtrlOrig,
                      wxTextCtrl *textCtrlTrans,
