@@ -1,5 +1,5 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
  *  Copyright (C) 2000-2005 Vaclav Slavik
  *
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: gexecute.cpp 1066 2007-03-21 17:27:08Z vaclavslavik $
+ *  $Id: gexecute.cpp 1175 2007-10-03 06:38:00Z vaclavslavik $
  *
  *  Gettext execution code
  *
@@ -205,10 +205,17 @@ bool ExecuteGettext(const wxString& cmdline_, wxString *stderrOutput)
 }
 
 
-wxProcess *ExecuteGettextNonblocking(const wxString& cmdline,
+wxProcess *ExecuteGettextNonblocking(const wxString& cmdline_,
                                      GettextProcessData *data,
                                      wxEvtHandler *parent)
 {
+    wxString cmdline(cmdline_);
+
+#ifdef __WXMAC__
+    wxString binary = cmdline.BeforeFirst(_T(' '));
+    cmdline = MacGetPathToBinary(binary) + cmdline.Mid(binary.length());
+#endif // __WXMAC__
+
     wxLogTrace(_T("poedit.execute"), _T("executing '%s'"), cmdline.c_str());
 
     TempLocaleSwitcher localeSwitcher(_T("C"));
