@@ -1,7 +1,7 @@
 /*
- *  This file is part of poEdit (http://www.poedit.net)
+ *  This file is part of Poedit (http://www.poedit.net)
  *
- *  Copyright (C) 2001-2005 Vaclav Slavik
+ *  Copyright (C) 2001-2007 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -21,7 +21,7 @@
  *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  *  DEALINGS IN THE SOFTWARE.
  *
- *  $Id: transmem.h 1066 2007-03-21 17:27:08Z vaclavslavik $
+ *  $Id: transmem.h 1177 2007-10-03 09:50:27Z vaclavslavik $
  *
  *  Translation memory database
  *
@@ -33,9 +33,6 @@
 #ifdef USE_TRANSMEM
 
 class WXDLLEXPORT wxString;
-#include <wx/list.h>
-class TranslationMemory;
-WX_DECLARE_LIST(TranslationMemory, TranslationMemoriesList);
 
 class DbTrans;
 class DbOrig;
@@ -81,7 +78,7 @@ class TranslationMemory
         static TranslationMemory *Create(const wxString& language, 
                                          const wxString& path = wxEmptyString);
 
-        void Release() { if (--m_refCnt == 0) delete this; }
+        void Release();
 
         ~TranslationMemory();
 
@@ -162,7 +159,6 @@ class TranslationMemory
         size_t   m_maxDelta, m_maxOmits;
         
         int      m_refCnt;
-        static TranslationMemoriesList ms_instances;
 };
 
 
